# $OpenBSD: mkregunreg.sh,v 1.1 2007/07/21 17:14:57 kili Exp $
#
# Create register and unregister scripts for updating the Cabal
# package registry.

usage() {
	echo "usage: sh mkregunreg.sh DESTDIR TRUEPREFIX" >&1 
	exit 1
}

if [ $# != 2 ]; then
	usage
fi

destdir="$1"
prefix="$2"
pkg_conf="$prefix/lib/ghc/package.conf"
ghc_pkg="$prefix/bin/ghc-pkg"

tmp=/tmp/.mkregunreg.$$
mkdir $tmp || exit 1
trap "rm -rf $tmp" 0 1 2 3 15

umask 022

my_ghc_pkg() {
	$destdir$ghc_pkg --global-conf $destdir$pkg_conf "$@"
}

for p in $(my_ghc_pkg list --simple-output); do
	echo $p $p
	set -- $(my_ghc_pkg field $p depends)
	shift
	for d; do
		echo $p $d
	done
done > $tmp/deps

exec > $destdir$prefix/lib/ghc/register.sh
chmod +x $destdir$prefix/lib/ghc/register.sh
cat <<- 'EOF'
	#! /bin/sh
	exec > /dev/null
EOF

tsort -r $tmp/deps |
while read p; do
	echo "$ghc_pkg register - << 'EOF'"
	my_ghc_pkg describe $p
	echo EOF
done
echo rm -f $pkg_conf.old

exec > $destdir$prefix/lib/ghc/unregister.sh
chmod +x $destdir$prefix/lib/ghc/unregister.sh
cat <<- 'EOF'
	#! /bin/sh
	exec > /dev/null
EOF

tsort $tmp/deps |
sed "s!^!$ghc_pkg unregister !"

cat <<- EOF
	rm -f $pkg_conf.old
	# If no packages are left, just remove the registry.
	case \$(tr -d '[:space:]' < $pkg_conf) in
	'[]')	rm -f $pkg_conf
	esac
EOF
